@@ -4,7 +4,7 @@ test_that("Test for bvarflat class", {
   
   test_lag <- 3
   etf_spec <- set_bvar_flat()
-  fit_test_bvar <- bvar_flat(etf_vix, test_lag, etf_spec)
+  fit_test_bvar <- bvar_flat(etf_vix, test_lag, bayes_spec = etf_spec)
   
   expect_s3_class(etf_spec, "bvharspec")
   expect_s3_class(fit_test_bvar, "bvarflat")
